==> haskell-hasql-transaction-0.7.1-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.7.1
id: hasql-transaction-0.7.1-92Kny4n1H5DJ0Zg65BKzvU
key: hasql-transaction-0.7.1-92Kny4n1H5DJ0Zg65BKzvU
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
abi: 9ceaf608a3efadd37dbb8f39db245ee8
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Statements
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-transaction-0.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-transaction-0.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasql-transaction-0.7.1
hs-libraries: HShasql-transaction-0.7.1-92Kny4n1H5DJ0Zg65BKzvU
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    bytestring-tree-builder-0.2.7.2-111uNrbIBEqC8eRXzi97I0
    contravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
    contravariant-extras-0.3.4-FcQOqizELA11CzEY1N4TUM
    hasql-1.3.0.3-FjYuSy7ll3zKPXFnjaZxlv mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-0.7.1-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.7.1
id: hasql-transaction-0.7.1-5lwrREriOIYBBFYsqCo0Yr
key: hasql-transaction-0.7.1-5lwrREriOIYBBFYsqCo0Yr
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
abi: 14ec2681ff351045799944bad6ac0b5d
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Statements
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-transaction-0.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-transaction-0.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasql-transaction-0.7.1
hs-libraries: HShasql-transaction-0.7.1-5lwrREriOIYBBFYsqCo0Yr
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    bytestring-tree-builder-0.2.7.3-Im7GDmQVH0m6ZFo8sTtX0C
    contravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
    contravariant-extras-0.3.4-FcQOqizELA11CzEY1N4TUM
    hasql-1.3.0.3-I9d1QmtfT1B484tdbt0lF0 mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
